@@ -15,6 +15,7 @@
 from fresco.response import Response
 
 __all__ = (
+    "OptionsLoadedException",
     "ResponseException",
     "NotFound",
     "Unauthorized",
@@ -154,3 +155,9 @@ class MissingRouteArg(BadRequest):
     """\
     A request argument was expected but not supplied.
     """
+
+
+class OptionsLoadedException(Exception):
+    """
+    The options object has already been loaded
+    """
