@@ -283,7 +283,9 @@ class Request(object):
         return key in self.form
 
     @property
-    def now(self, utcnow=datetime.datetime.now, utc=datetime.timezone.utc):  # type: ignore
+    def now(  # type: ignore
+        self, utcnow=datetime.datetime.now, utc=datetime.timezone.utc
+    ):
         """
         Return a timezone-aware UTC datetime instance. The value returned is
         guaranteed to be constant throughout the lifetime of the request.
