@@ -12,16 +12,15 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-from __future__ import absolute_import
-
 import pytest
 
-from fresco import FrescoApp, GET, Response
+from fresco import FrescoApp
+from fresco.response import Response
+from fresco.routing import GET
 from fresco.requestcontext import RequestContext
 
 
 class TestRequestContext(object):
-
     def test_instantiation(self):
         """
         Can we cleanly instantiate a RequestContext object?
@@ -29,16 +28,16 @@ class TestRequestContext(object):
         RequestContext()
 
     def test_app_populates_request_object(self):
-
         def view():
             from fresco.core import context
+
             assert context.request is not None
-            return Response([''])
+            return Response([""])
 
         app = FrescoApp()
-        app.route('/', GET, view)
+        app.route("/", GET, view)
 
-        with app.requestcontext('/'):
+        with app.requestcontext("/"):
             app.view()
 
     def test_context_returns_correct_request_for_each_app(self):
@@ -52,6 +51,7 @@ class TestRequestContext(object):
 
         def view():
             from fresco.core import context
+
             request_id = id(context.request)
 
             def generate_response():
@@ -59,14 +59,15 @@ class TestRequestContext(object):
                     assert id(context.request) == request_id
                     calls.append(current_thread().ident)
                     sleep(0.0001)
-                    yield str(request_id).encode('ascii')
+                    yield str(request_id).encode("ascii")
+
             return Response(list(generate_response()))
 
         app = FrescoApp()
-        app.route('/', GET, view)
+        app.route("/", GET, view)
 
         def do_request():
-            with app.requestcontext('/'):
+            with app.requestcontext("/"):
                 app.view()
 
         threads = [Thread(target=do_request) for i in range(threadcount)]
@@ -79,7 +80,7 @@ class TestRequestContext(object):
         assert len(calls) == threadcount * itercount
 
         # Check that threaded requests were genuinely interleaved
-        for i1, i2 in zip(calls[:itercount - 1], calls[1:itercount]):
+        for i1, i2 in zip(calls[: itercount - 1], calls[1:itercount]):
             if i1 != i2:
                 break
         else:
